summaryrefslogtreecommitdiff
path: root/sfx2/source/control/request.cxx
diff options
context:
space:
mode:
authorMikhail Voytenko <mav@openoffice.org>2011-01-07 17:14:47 +0100
committerMikhail Voytenko <mav@openoffice.org>2011-01-07 17:14:47 +0100
commitdcd8e4664d9a284c24ceb0360cab0606b22cf86d (patch)
tree19c2817590445d01056d62e793f68892eb1b23b4 /sfx2/source/control/request.cxx
parent71747dd58636847fdfda6b5e4029a78d5e0cccfb (diff)
removetooltypes: #i112600# remove tooltypes
Diffstat (limited to 'sfx2/source/control/request.cxx')
-rw-r--r--sfx2/source/control/request.cxx130
1 files changed, 65 insertions, 65 deletions
diff --git a/sfx2/source/control/request.cxx b/sfx2/source/control/request.cxx
index 88a52d0ad0bf..05c9a8da0eb0 100644
--- a/sfx2/source/control/request.cxx
+++ b/sfx2/source/control/request.cxx
@@ -76,13 +76,13 @@ struct SfxRequest_Impl: public SfxListener
SfxPoolItem* pRetVal; // R"uckgabewert geh"ort sich selbst
SfxShell* pShell; // ausgef"uhrt an dieser Shell
const SfxSlot* pSlot; // ausgef"uhrter Slot
- USHORT nModifier; // welche Modifier waren gedrueckt?
- BOOL bDone; // "uberhaupt ausgef"uhrt
- BOOL bIgnored; // vom User abgebrochen
- BOOL bCancelled; // nicht mehr zustellen
- BOOL bUseTarget; // aTarget wurde von Applikation gesetzt
- USHORT nCallMode; // Synch/Asynch/API/Record
- BOOL bAllowRecording;
+ sal_uInt16 nModifier; // welche Modifier waren gedrueckt?
+ sal_Bool bDone; // "uberhaupt ausgef"uhrt
+ sal_Bool bIgnored; // vom User abgebrochen
+ sal_Bool bCancelled; // nicht mehr zustellen
+ sal_Bool bUseTarget; // aTarget wurde von Applikation gesetzt
+ sal_uInt16 nCallMode; // Synch/Asynch/API/Record
+ sal_Bool bAllowRecording;
SfxAllItemSet* pInternalArgs;
SfxViewFrame* pViewFrame;
@@ -92,9 +92,9 @@ struct SfxRequest_Impl: public SfxListener
: pAnti( pOwner)
, pPool(0)
, nModifier(0)
- , bCancelled(FALSE)
+ , bCancelled(sal_False)
, nCallMode( SFX_CALLMODE_SYNCHRON )
- , bAllowRecording( FALSE )
+ , bAllowRecording( sal_False )
, pInternalArgs( 0 )
, pViewFrame(0)
{}
@@ -162,8 +162,8 @@ SfxRequest::SfxRequest
DBG_MEMTEST();
pImp->bAllowRecording = rOrig.pImp->bAllowRecording;
- pImp->bDone = FALSE;
- pImp->bIgnored = FALSE;
+ pImp->bDone = sal_False;
+ pImp->bIgnored = sal_False;
pImp->pRetVal = 0;
pImp->pShell = 0;
pImp->pSlot = 0;
@@ -186,7 +186,7 @@ SfxRequest::SfxRequest
SfxRequest::SfxRequest
(
SfxViewFrame* pViewFrame,
- USHORT nSlotId
+ sal_uInt16 nSlotId
)
@@ -205,16 +205,16 @@ SfxRequest::SfxRequest
{
DBG_MEMTEST();
- pImp->bDone = FALSE;
- pImp->bIgnored = FALSE;
+ pImp->bDone = sal_False;
+ pImp->bIgnored = sal_False;
pImp->SetPool( &pViewFrame->GetPool() );
pImp->pRetVal = 0;
pImp->pShell = 0;
pImp->pSlot = 0;
pImp->nCallMode = SFX_CALLMODE_SYNCHRON;
- pImp->bUseTarget = FALSE;
+ pImp->bUseTarget = sal_False;
pImp->pViewFrame = pViewFrame;
- if( pImp->pViewFrame->GetDispatcher()->GetShellAndSlot_Impl( nSlotId, &pImp->pShell, &pImp->pSlot, TRUE, TRUE ) )
+ if( pImp->pViewFrame->GetDispatcher()->GetShellAndSlot_Impl( nSlotId, &pImp->pShell, &pImp->pSlot, sal_True, sal_True ) )
{
pImp->SetPool( &pImp->pShell->GetPool() );
pImp->xRecorder = SfxRequest::GetMacroRecorder( pViewFrame );
@@ -248,14 +248,14 @@ SfxRequest::SfxRequest
{
DBG_MEMTEST();
- pImp->bDone = FALSE;
- pImp->bIgnored = FALSE;
+ pImp->bDone = sal_False;
+ pImp->bIgnored = sal_False;
pImp->SetPool( &rPool );
pImp->pRetVal = 0;
pImp->pShell = 0;
pImp->pSlot = 0;
pImp->nCallMode = nMode;
- pImp->bUseTarget = FALSE;
+ pImp->bUseTarget = sal_False;
}
SfxRequest::SfxRequest
@@ -271,14 +271,14 @@ SfxRequest::SfxRequest
{
DBG_MEMTEST();
- pImp->bDone = FALSE;
- pImp->bIgnored = FALSE;
+ pImp->bDone = sal_False;
+ pImp->bIgnored = sal_False;
pImp->SetPool( &rPool );
pImp->pRetVal = 0;
pImp->pShell = 0;
pImp->pSlot = 0;
pImp->nCallMode = nMode;
- pImp->bUseTarget = FALSE;
+ pImp->bUseTarget = sal_False;
TransformParameters( nSlot, rArgs, *pArgs, pSlot );
}
@@ -286,8 +286,8 @@ SfxRequest::SfxRequest
SfxRequest::SfxRequest
(
- USHORT nSlotId,
- USHORT nMode,
+ sal_uInt16 nSlotId,
+ sal_uInt16 nMode,
const SfxAllItemSet& rSfxArgs
)
@@ -299,37 +299,37 @@ SfxRequest::SfxRequest
{
DBG_MEMTEST();
- pImp->bDone = FALSE;
- pImp->bIgnored = FALSE;
+ pImp->bDone = sal_False;
+ pImp->bIgnored = sal_False;
pImp->SetPool( rSfxArgs.GetPool() );
pImp->pRetVal = 0;
pImp->pShell = 0;
pImp->pSlot = 0;
pImp->nCallMode = nMode;
- pImp->bUseTarget = FALSE;
+ pImp->bUseTarget = sal_False;
}
//--------------------------------------------------------------------
-USHORT SfxRequest::GetCallMode() const
+sal_uInt16 SfxRequest::GetCallMode() const
{
return pImp->nCallMode;
}
//--------------------------------------------------------------------
-BOOL SfxRequest::IsSynchronCall() const
+sal_Bool SfxRequest::IsSynchronCall() const
{
return SFX_CALLMODE_SYNCHRON == ( SFX_CALLMODE_SYNCHRON & pImp->nCallMode );
}
//--------------------------------------------------------------------
-void SfxRequest::SetSynchronCall( BOOL bSynchron )
+void SfxRequest::SetSynchronCall( sal_Bool bSynchron )
{
if ( bSynchron )
pImp->nCallMode |= SFX_CALLMODE_SYNCHRON;
else
- pImp->nCallMode &= ~(USHORT) SFX_CALLMODE_SYNCHRON;
+ pImp->nCallMode &= ~(sal_uInt16) SFX_CALLMODE_SYNCHRON;
}
void SfxRequest::SetInternalArgs_Impl( const SfxAllItemSet& rArgs )
@@ -456,7 +456,7 @@ void SfxRequest::AppendItem(const SfxPoolItem &rItem)
//--------------------------------------------------------------------
-void SfxRequest::RemoveItem( USHORT nID )
+void SfxRequest::RemoveItem( sal_uInt16 nID )
{
if (pArgs)
{
@@ -470,8 +470,8 @@ void SfxRequest::RemoveItem( USHORT nID )
const SfxPoolItem* SfxRequest::GetArg
(
- USHORT nSlotId, // Slot-Id oder Which-Id des Parameters
- FASTBOOL bDeep, // FALSE: nicht in Parent-ItemSets suchen
+ sal_uInt16 nSlotId, // Slot-Id oder Which-Id des Parameters
+ int bDeep, // sal_False: nicht in Parent-ItemSets suchen
TypeId aType // != 0: RTTI Pruefung mit Assertion
) const
{
@@ -483,7 +483,7 @@ const SfxPoolItem* SfxRequest::GetArg
const SfxPoolItem* SfxRequest::GetItem
(
const SfxItemSet* pArgs,
- USHORT nSlotId, // Slot-Id oder Which-Id des Parameters
+ sal_uInt16 nSlotId, // Slot-Id oder Which-Id des Parameters
bool bDeep, // false: nicht in Parent-ItemSets suchen
TypeId aType // != 0: RTTI Pruefung mit Assertion
)
@@ -509,12 +509,12 @@ const SfxPoolItem* SfxRequest::GetItem
...
// ein Beispiel ohne Verwendung des Makros
const SfxInt32Item *pPosItem = (const SfxUInt32Item*)
- rReq.GetArg( SID_POS, FALSE, TYPE(SfxInt32Item) );
- USHORT nPos = pPosItem ? pPosItem->GetValue() : 0;
+ rReq.GetArg( SID_POS, sal_False, TYPE(SfxInt32Item) );
+ sal_uInt16 nPos = pPosItem ? pPosItem->GetValue() : 0;
// ein Beispiel mit Verwendung des Makros
- SFX_REQUEST_ARG(rReq, pSizeItem, SfxInt32Item, SID_SIZE, FALSE);
- USHORT nSize = pSizeItem ? pPosItem->GetValue() : 0;
+ SFX_REQUEST_ARG(rReq, pSizeItem, SfxInt32Item, SID_SIZE, sal_False);
+ sal_uInt16 nSize = pSizeItem ? pPosItem->GetValue() : 0;
...
}
@@ -528,7 +528,7 @@ const SfxPoolItem* SfxRequest::GetItem
if ( pArgs )
{
// ggf. in Which-Id umrechnen
- USHORT nWhich = pArgs->GetPool()->GetWhich(nSlotId);
+ sal_uInt16 nWhich = pArgs->GetPool()->GetWhich(nSlotId);
// ist das Item gesetzt oder bei bDeep==TRUE verf"ugbar?
const SfxPoolItem *pItem = 0;
@@ -574,7 +574,7 @@ void SfxRequest::Done
erfragt wurden, ggf. 0 falls keine
Parameter gesetzt wurden */
- FASTBOOL bKeep /* TRUE (default)
+ int bKeep /* sal_True (default)
'rSet' wird gepeichert und ist "uber
GetArgs() abfragbar
@@ -634,7 +634,7 @@ void SfxRequest::Done
//--------------------------------------------------------------------
-void SfxRequest::Done( BOOL bRelease )
+void SfxRequest::Done( sal_Bool bRelease )
// [<SfxRequest::Done(SfxItemSet&)>]
{
Done_Impl( pArgs );
@@ -652,7 +652,7 @@ void SfxRequest::ForgetAllArgs()
//--------------------------------------------------------------------
-BOOL SfxRequest::IsCancelled() const
+sal_Bool SfxRequest::IsCancelled() const
{
return pImp->bCancelled;
}
@@ -668,7 +668,7 @@ void SfxRequest::Cancel()
*/
{
- pImp->bCancelled = TRUE;
+ pImp->bCancelled = sal_True;
pImp->SetPool( 0 );
DELETEZ( pArgs );
}
@@ -694,7 +694,7 @@ void SfxRequest::Ignore()
{
// als tats"achlich ausgef"uhrt markieren
- pImp->bIgnored = TRUE;
+ pImp->bIgnored = sal_True;
}
//--------------------------------------------------------------------
@@ -715,7 +715,7 @@ void SfxRequest::Done_Impl
{
// als tats"achlich ausgef"uhrt markieren
- pImp->bDone = TRUE;
+ pImp->bDone = sal_True;
// nicht Recorden
if ( !pImp->xRecorder.is() )
@@ -751,8 +751,8 @@ void SfxRequest::Done_Impl
{
// des Property als SfxPoolItem besorgen
const SfxPoolItem *pItem;
- USHORT nWhich = rPool.GetWhich(pImp->pSlot->GetSlotId());
- SfxItemState eState = pSet ? pSet->GetItemState( nWhich, FALSE, &pItem ) : SFX_ITEM_UNKNOWN;
+ sal_uInt16 nWhich = rPool.GetWhich(pImp->pSlot->GetSlotId());
+ SfxItemState eState = pSet ? pSet->GetItemState( nWhich, sal_False, &pItem ) : SFX_ITEM_UNKNOWN;
#ifdef DBG_UTIL
if ( SFX_ITEM_SET != eState )
{
@@ -786,13 +786,13 @@ void SfxRequest::Done_Impl
for ( const SfxPoolItem* pItem = aIter.FirstItem(); pItem; pItem = aIter.NextItem() )
{
// die Slot-Id f"ur das einzelne Item ermitteln
- USHORT nSlotId = rPool.GetSlotId( pItem->Which() );
+ sal_uInt16 nSlotId = rPool.GetSlotId( pItem->Which() );
if ( nSlotId == nSlot )
{
// mit Hosentr"ager und G"urtel reparieren des falschen Flags
DBG_ERROR( "recursion RecordPerItem - use RecordPerSet!" );
SfxSlot *pSlot = (SfxSlot*) pImp->pSlot;
- pSlot->nFlags &= ~((ULONG)SFX_SLOT_RECORDPERITEM);
+ pSlot->nFlags &= ~((sal_uIntPtr)SFX_SLOT_RECORDPERITEM);
pSlot->nFlags &= SFX_SLOT_RECORDPERSET;
}
@@ -813,7 +813,7 @@ void SfxRequest::Done_Impl
//--------------------------------------------------------------------
-BOOL SfxRequest::IsDone() const
+sal_Bool SfxRequest::IsDone() const
/* [Beschreibung]
@@ -823,7 +823,7 @@ BOOL SfxRequest::IsDone() const
der Kontext f"ur diesen Request falsch war, dieses aber nicht "uber
eine separate <SfxShell> realisiert wurde.
- SfxRequest-Instanzen, die hier FALSE liefern, werden nicht recorded.
+ SfxRequest-Instanzen, die hier sal_False liefern, werden nicht recorded.
[Querverweise]
@@ -881,7 +881,7 @@ com::sun::star::uno::Reference< com::sun::star::frame::XDispatchRecorder > SfxRe
return xRecorder;
}
-BOOL SfxRequest::HasMacroRecorder( SfxViewFrame* pView )
+sal_Bool SfxRequest::HasMacroRecorder( SfxViewFrame* pView )
{
return GetMacroRecorder( pView ).is();
}
@@ -889,12 +889,12 @@ BOOL SfxRequest::HasMacroRecorder( SfxViewFrame* pView )
//--------------------------------------------------------------------
-BOOL SfxRequest::IsAPI() const
+sal_Bool SfxRequest::IsAPI() const
/* [Beschreibung]
- Liefert TRUE, wenn dieser SfxRequest von einer API (z.B. BASIC)
- erzeugt wurde, sonst FALSE.
+ Liefert sal_True, wenn dieser SfxRequest von einer API (z.B. BASIC)
+ erzeugt wurde, sonst sal_False.
*/
{
@@ -904,15 +904,15 @@ BOOL SfxRequest::IsAPI() const
//--------------------------------------------------------------------
-FASTBOOL SfxRequest::IsRecording() const
+int SfxRequest::IsRecording() const
/* [Beschreibung]
- Liefert TRUE, wenn dieser SfxRequest recorded werden soll, d.h.
+ Liefert sal_True, wenn dieser SfxRequest recorded werden soll, d.h.
1. zu Zeit ein Makro aufgezeichnet wird
2. dieser Request "uberhaupt aufgezeichnet wird
3. der Request nicht von reiner API (z.B. BASIC) ausgeht,
- sonst FALSE.
+ sonst sal_False.
*/
{
@@ -920,13 +920,13 @@ FASTBOOL SfxRequest::IsRecording() const
}
//--------------------------------------------------------------------
-void SfxRequest::SetModifier( USHORT nModi )
+void SfxRequest::SetModifier( sal_uInt16 nModi )
{
pImp->nModifier = nModi;
}
//--------------------------------------------------------------------
-USHORT SfxRequest::GetModifier() const
+sal_uInt16 SfxRequest::GetModifier() const
{
return pImp->nModifier;
}
@@ -954,17 +954,17 @@ void SfxRequest::SetTarget( const String &rTarget )
{
pImp->aTarget = rTarget;
- pImp->bUseTarget = TRUE;
+ pImp->bUseTarget = sal_True;
}
-void SfxRequest::AllowRecording( BOOL bSet )
+void SfxRequest::AllowRecording( sal_Bool bSet )
{
pImp->bAllowRecording = bSet;
}
-BOOL SfxRequest::AllowsRecording() const
+sal_Bool SfxRequest::AllowsRecording() const
{
- BOOL bAllow = pImp->bAllowRecording;
+ sal_Bool bAllow = pImp->bAllowRecording;
if( !bAllow )
bAllow = ( SFX_CALLMODE_API != ( SFX_CALLMODE_API & pImp->nCallMode ) ) &&
( SFX_CALLMODE_RECORD == ( SFX_CALLMODE_RECORD & pImp->nCallMode ) );